==> migrate-4.1.4.src.tar.gz: migrate-4.1.4/src/src/speciate.h <==
/* speciate.h */
// contains declarations for speciate.c
//
extern MYREAL eventtime_single(world_fmt *world, long pop, long timeslice, long *lineages, double age, char * event, long *to, long *from);

extern node * set_type2(world_fmt *world, node *p, node *q, char *custm2);
extern MYREAL set_type(world_fmt *world, long topop, long frompop, char *custm2, long numpop);
extern long newtree_update (world_fmt * world, long g, boolean assign);
extern long speciation_from(long to, proposal_fmt * proposal);
extern void loopcleanup(boolean assign, world_fmt * world, proposal_fmt *proposal, long oldpop, timelist_fmt *timevector);
extern long init_speciesvector(world_fmt * world);
extern void fill_speciesvector(world_fmt*world, option_fmt *options);
extern long propose_new_spec_mu_old(world_fmt * world, MYREAL *oldmu, MYREAL *oldsigma, MYREAL *newmu, MYREAL *newsigma, long which, boolean *is_mu);
extern long propose_new_spec_mu(world_fmt * world, long which, boolean *is_mu, MYREAL *newparam);
extern MYREAL wait_event_species(world_fmt *world, vtlist *tli, MYREAL t0, MYREAL t1, boolean waitonly, MYREAL *eventprob);
extern MYREAL wait_D(long pop, MYREAL t0, MYREAL t1, long *lineages, world_fmt *world);
extern void set_first_speciestree(node *mrca, world_fmt *world);
extern void species_datarecorder(world_fmt *world);
extern species_fmt * get_species_model(long to, species_fmt * s , long ssize);
extern void species_datarecorder(world_fmt *world);
extern void construct_locusspecies_histogram(world_fmt *world, long locus, MYREAL *mini, MYREAL *maxi, float **results);
extern void read_species_record(long masternumbinall, MYREAL *params, long *n, MYREAL *oldmeans, MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, char **inptr);
#if defined(MPI) && !defined(PARALIO) /* */
void print_species_record(float *temp, long *z, world_fmt *world);
#else
void  print_species_record(char *temp, long *c, world_fmt * world);
#endif

==> migrate-4.2.2a.src.tar.gz: migrate-4.2.2a/src/src/speciate.h <==
/* speciate.h */
// contains declarations for speciate.c
//
#ifndef __SPECIATE__H
#define  __SPECIATE__H
extern MYREAL log_prob_wait_speciate(MYREAL t0, MYREAL t1, MYREAL mu, MYREAL sigma, species_fmt *s);
extern MYREAL log_point_prob_speciate(MYREAL t1, MYREAL mu, MYREAL sigma, species_fmt * s);
extern MYREAL eventtime_single(proposal_fmt *proposal, world_fmt *world, long pop, long timeslice, long *lineages, double age, char * event, long *to, long *from);

extern node * set_type2(world_fmt *world, node *p, node *q, char *custm2);
extern MYREAL set_type(world_fmt *world, long topop, long frompop, char *custm2, long numpop);
extern long newtree_update (world_fmt * world, long g, boolean assign);
extern long speciation_from(long to, proposal_fmt * proposal);
extern void loopcleanup(boolean assign, world_fmt * world, proposal_fmt *proposal, long oldpop, timelist_fmt *timevector);
extern long init_speciesvector(world_fmt * world);
extern void fill_speciesvector(world_fmt*world, option_fmt *options);
extern long propose_new_spec_mu_old(world_fmt * world, MYREAL *oldmu, MYREAL *oldsigma, MYREAL *newmu, MYREAL *newsigma, long which, boolean *is_mu);
extern long propose_new_spec_mu(world_fmt * world, long which, boolean *is_mu, MYREAL *newparam);
extern MYREAL wait_event_species(world_fmt *world, vtlist *tli, MYREAL t0, MYREAL t1, boolean waitonly, MYREAL *eventprob);
extern MYREAL wait_D(long pop, MYREAL t0, MYREAL t1, long *lineages, world_fmt *world);
extern void set_first_speciestree(node *mrca, world_fmt *world);
extern void species_datarecorder(world_fmt *world);
extern species_fmt * get_species_model(long to, species_fmt * s , long ssize);
extern void species_datarecorder(world_fmt *world);
extern void construct_locusspecies_histogram(world_fmt *world, long locus, MYREAL *mini, MYREAL *maxi, float **results);
extern void read_species_record(long masternumbinall, MYREAL *params, long *n, MYREAL *oldmeans, MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, char **inptr);
extern void record_parameters(world_fmt *world);
#if defined(MPI) && !defined(PARALIO) /* */
void print_species_record(float *temp, long *z, world_fmt *world);
#else
void  print_species_record(char *temp, long *c, world_fmt * world);
#endif
#endif
